# thop
torchhelper 2.0

## outline

- 整合框架：快捷的注册模型的方法、日志输出、绘图、checkpoint流程
- 以试验为单位的模型训练过程，能够：更改参数重新训练、更改参数继续训练、预加载模型继续训练，
- 搭建好后，能够在jupyter中训练，并在训练完成后释放GPU

- 充分解耦：
saver只需要管自己在哪里存什么，存多少，加载什么，其他什么都不用管
logger只需要管在哪里输出什么，有多少项需要输出，输出是否要换行
experiment只需要管哪些代码和试验相关密切需要存储，哪些在试验过程中生成的文件需要记录，其他什么都不需要管
训练过程中只需要知道要记录哪些变量作为日志，日志的输出怎么来不需要在训练的过程中处理，而是交给了callback来完成，训练只需要训练就可以了。

唯一联系密切一些的是trainer和callback，因为用了一些Python的语法糖。


## 测试
```bash
python -m pytest
```
